Contrib Packages
================

Here is where we keep the batteries. These packages are Django apps that add
functionality or widgets to Widgy.

.. toctree::
    :maxdepth: 1

    page-builder/index
    form-builder/index
    widgy-mezzanine/index
    review-queue/index
